@@ -5,7 +5,7 @@ needs to communicate with the user it does so through the agent.  The
 agent has a QDialog as a class member, and agent_dialog.cpp manages
 that dialog.  
 
-Copyright (C) 2013-2015
+Copyright (C) 2013-2017
 by: Andrew J. Bibb
 License: MIT 
 
@@ -50,7 +50,7 @@ AgentDialog::AgentDialog(QWidget* parent)
   cli_browsers.clear();	  
  	cli_browsers << "lynx" << "w3m" << "links" << "elinks";
  	gui_browsers.clear();
-	gui_browsers << "google-chrome" << "google-chrome-unstable" << "chromium" << "opera";									// blink based 	  
+	gui_browsers << "google-chrome" << "google-chrome-unstable" << "chromium" << "opera" << "brave";			// blink based 	  
 	gui_browsers << "firefox" << "seamonkey";																															// gecko based 	  
 	gui_browsers << "qupzilla" << "luakit" << "dwb" << "jumanji" << "midoir" << "surf" << "vimprobable";	// webkit based 	  
 	gui_browsers << "konqueror" << "dillo" << "xdg-open";																									// other	 	  
@@ -250,6 +250,7 @@ void AgentDialog::updateBrowserChoice(const QModelIndex & current, const QModelI
 	
 	ui.lineEdit_browser->setText(current.data().toString());
 }
+
 //
 //  Slot to clear selection in the browser list view
 //  Called when ui.lineEdit_browser textEdited() signal is emitted
@@ -257,6 +258,7 @@ void AgentDialog::enteringBrowser()
 {
 	ui.listView_browsers->selectionModel()->clearSelection();
 }
+
 //
 //	Slot to launch the selected browser
 //	Called when ui.pushButton_launch_browser is pressed
@@ -300,4 +302,6 @@ void AgentDialog::launchBrowser()
 	} else {
 		process->startDetached(chosenBrowser, QStringList(ui.lineEdit_url->text()) );	
 	}
+	
+	return;
 }
