@@ -3,7 +3,7 @@
 Code to manage the primary user interface to include the QDialog the
 user interfaces with and the system tray icon.  
 
-Copyright (C) 2013-2015
+Copyright (C) 2013-2017
 by: Andrew J. Bibb
 License: MIT 
 
@@ -54,7 +54,7 @@ DEALINGS IN THE SOFTWARE.
 # include "./code/counter/counter.h"
 # include "./code/notify/notify.h"
 # include "./code/iconman/iconman.h"
-
+# include "./code/vpn_agent/vpnagent.h"
 
 //  Two of the connman.Manager query functions will return an array of structures.
 //  This struct provides a receiving element we can use to collect the return data.
@@ -64,6 +64,7 @@ struct arrayElement
   QMap<QString,QVariant> objmap;
 };
 
+
 //
 // custom QFrame containing a QToolButton that will emit a button id
 class idButton : public QFrame
@@ -87,20 +88,6 @@ class idButton : public QFrame
     void buttonClicked(bool);
 };
 
-//
-// custom QFrame containing a QProgressBar
-class SignalBar : public QFrame
-{
-  Q_OBJECT
-  
-  public:
-    SignalBar (QWidget*);
-    inline void setBarValue (const int& val) {bar->setValue(val);}
-    
-  private:
-    QProgressBar* bar;      
-};
-
 //
 //  The main program class based on a QDialog
 class ControlBox : public QDialog
@@ -124,24 +111,28 @@ class ControlBox : public QDialog
   private:
   // members 
     Ui::ControlBox ui;
-    quint8 q8_errors;
+    quint16 q16_errors;
     QMap<QString,QVariant>  properties_map;
     QList<arrayElement>   services_list;
     QList<arrayElement>   technologies_list;
     QList<arrayElement>   wifi_list;
     QList<arrayElement>   peer_list;
+    QList<arrayElement> 	vpn_list;
     ConnmanAgent* agent;
+    ConnmanVPNAgent* vpnagent;
     ConnmanCounter* counter;  
     NotifyClient* notifyclient; 
     short wifi_interval;    
     quint32 counter_accuracy; 
     quint32 counter_period;       
-    QDBusInterface* iface_manager;
+    QDBusInterface* con_manager;
+    QDBusInterface* vpn_manager;
     QSystemTrayIcon*  trayicon;
     QMenu* trayiconmenu;
     QMenu* tech_submenu;
     QMenu* info_submenu;
     QMenu* wifi_submenu;
+    QMenu* vpn_submenu;
     QMenu* mvsrv_menu; 
     QActionGroup* minMaxGroup;
     QActionGroup* moveGroup;
@@ -158,10 +149,11 @@ class ControlBox : public QDialog
   
   // functions
     int managerRescan(const int& srv = 0);
-    void assemblePage1();
-    void assemblePage2();
-    void assemblePage3();
-    void assemblePage4();
+    void assembleTabStatus();
+    void assembleTabDetails();
+    void assembleTabWireless();
+    void assembleTabVPN();
+    void assembleTabCounters();
     void assembleTrayIcon();
     void sendNotifications();
     bool getProperties();
@@ -169,10 +161,10 @@ class ControlBox : public QDialog
     bool getServices();
     bool getArray(QList<arrayElement>&, const QDBusMessage&);
     bool getMap(QMap<QString,QVariant>&, const QDBusMessage&); 
-    static bool extractMapData(QMap<QString,QVariant>&,const QVariant&);
-    void logErrors(const quint8&);
+    void logErrors(const quint16&);
     QString readResourceText(const char*);
     void clearCounters();
+    QString getNickName(const QDBusObjectPath&);
 
   private slots:
     void updateDisplayWidgets();
@@ -184,20 +176,23 @@ class ControlBox : public QDialog
     void disconnectPressed();
     void removePressed();
     void dbsPropertyChanged(QString,QDBusVariant);
-    void dbsServicesChanged(QMap<QString, QVariant>, QList<QDBusObjectPath>, QDBusMessage);
-    void dbsPeersChanged(QMap<QString, QVariant>, QList<QDBusObjectPath>, QDBusMessage);
+    void dbsServicesChanged(QList<QVariant>, QList<QDBusObjectPath>, QDBusMessage);
+    void dbsPeersChanged(QList<QVariant>, QList<QDBusObjectPath>, QDBusMessage);
     void dbsServicePropertyChanged(QString, QDBusVariant, QDBusMessage);
     void dbsTechnologyPropertyChanged(QString, QDBusVariant, QDBusMessage);
     void dbsTechnologyAdded(QDBusObjectPath, QVariantMap);
     void dbsTechnologyRemoved(QDBusObjectPath);
     void scanWiFi();
+    void wifiIDPass(const QString& obj_path = QString() );
     void toggleOfflineMode(bool);
     void toggleTrayIcon(bool);
     void togglePowered(QString, bool);
+    void toggleTethered(QString, bool);
     void minMaxWindow(QAction* = 0);
     void techSubmenuTriggered(QAction* = 0);
     void infoSubmenuTriggered(QAction* = 0);
     void wifiSubmenuTriggered(QAction* = 0);
+    void vpnSubmenuTriggered(QAction* = 0);
     void getServiceDetails(int);
     void showWhatsThis();
     inline void trayNotifications(bool checked) {if (checked) ui.checkBox_notifydaemon->setChecked(false);}
@@ -215,6 +210,7 @@ class ControlBox : public QDialog
     void cleanUp();
     void callColorDialog();
     void iconColorChanged(const QString&);
+    void setStateRescan(bool);
 };
 
 #endif
