@@ -3,7 +3,7 @@
 Class to manage icons and allow the user to provide substitutions based
 on the the system theme. 
 
-Copyright (C) 2015
+Copyright (C) 2015-2017
 by: Andrew J. Bibb
 License: MIT
 
@@ -39,6 +39,7 @@ DEALINGS IN THE SOFTWARE.
 # include <QSettings>
 # include <QMessageBox>
 # include <QProcessEnvironment>
+# include <QDirIterator>
 
 // Constructor
 IconManager::IconManager(QObject* parent) : QObject(parent) 
@@ -47,7 +48,7 @@ IconManager::IconManager(QObject* parent) : QObject(parent)
   // APP defined in resource.h
   QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
   QString home = env.value("HOME");
-  cfg = QString(env.value("XDG_CONFIG_HOME", QString(QDir::homePath())) + "/.config/%1/%1.icon").arg(QString(APP).toLower() );	
+  cfg = QString(env.value("XDG_CONFIG_HOME", QString(QDir::homePath()) + "/.config") + "/%1/%1.icon").arg(QString(APP).toLower() );	
 	
 	// Set the qrc data member
 	qrc = QString(":/text/text/icon_def.txt");
@@ -132,7 +133,7 @@ QIcon IconManager::getIcon(const QString& name)
 }
 
 //
-// Function to return a QString containing the icon theme name or resource path
+// Function to return a QString containing the fully qualified icon name or resource path
 QString IconManager::getIconName(const QString& name)
 {
 	// Data members
@@ -141,7 +142,7 @@ QString IconManager::getIconName(const QString& name)
 	// If the internal theme is being used (and the user has not
 	// messed up the local config file) use that first.
 	if (QIcon::themeName() == INTERNAL_THEME ) {
-		const QString res_path = ie.resource_path.section('|', 0, 0).simplified();
+		const QString res_path = ie.resource_path.section(' ', 0, 0).simplified();
 		if (QFileInfo(res_path).exists() )
 			return res_path;
 	}	// if using internal theme
@@ -150,27 +151,35 @@ QString IconManager::getIconName(const QString& name)
 	if (ie.theme_names.size() > 0 ) {
 		for (int i = 0; i < ie.theme_names.size(); ++i) {
 			QString theme_icon = ie.theme_names.at(i).section('|', 0, 0).simplified(); 
-			if (QIcon::hasThemeIcon(theme_icon) )
-				return theme_icon;
+			if (QIcon::hasThemeIcon(theme_icon) ) {
+				QStringList filter_list;
+				filter_list << "24x24" << "22x22" << "16x16"; 
+				QString rtn = findQualifiedName(theme_icon, filter_list);
+				if (! rtn.isEmpty() ) return rtn;
+			}	// if has ThemeIcon
 		}	// for		
 	}	// if namelist contains entries
 	
 	// Next look for a freedesktop.org named icon
 	if (! ie.fdo_name.isEmpty() ) {
 		QString theme_icon = ie.fdo_name.section('|', 0, 0).simplified();
-		if (QIcon::hasThemeIcon(theme_icon) )
-			return theme_icon;
+		if (QIcon::hasThemeIcon(theme_icon) ) {
+			QStringList filter_list;
+			filter_list << "24x24" << "22x22" << "16x16"; 
+			QString rtn = findQualifiedName(theme_icon, filter_list);
+			if (! rtn.isEmpty() ) return rtn;
+		}	// if has ThemeIcon
 	}	// if freedesktop name not empty
 		
 	// Then look for hardcoded name in the users config dir
 	if (! ie.resource_path.isEmpty() ) {
-		const QString res_path = ie.fdo_name.section('|', 0, 0).simplified();
+		const QString res_path = ie.fdo_name.section(' ', 0, 0).simplified();
 		if (QFileInfo(res_path).exists() )
 			return  res_path;
 	}
 	
 	// Last stop is our fallback hard coded into the program
-	const QString res_path = getFallback(name).section('|', 0, 0).simplified();
+	const QString res_path = getFallback(name).section(' ', 0, 0).simplified();
 	return res_path;
  }
 
@@ -333,7 +342,7 @@ void IconManager::makeLocalFile()
 			if (ctr <= maxloop && f_cfg.copy(bak) ) { 
 				QMessageBox::StandardButton dia_rtn = QMessageBox::information(0, QString(APP),
 					tr("A new icon definition file will be installed to <b>%1</b> and a backup of the old definition file has been created as <b>%2</b> \
-						<p>If the original definition file was customized you wish to retain those changes you will need to manually merge them into the new file.	\
+						<p>If the original definition file was customized and you wish to retain those changes you will need to manually merge them into the new file.	\
 						<p>If the original was never customized or you just wish to delete the backup now you may select <i>Discard</i> to delete the backup or <i>Save</i> to retain it.").arg(cfg).arg(bak),
 					QMessageBox::Save | QMessageBox::Discard,
 					QMessageBox::Save);
@@ -464,3 +473,43 @@ QPixmap IconManager::processArt(const QString& res, const QColor& color)
 	
 	return QPixmap::fromImage(dest);
 }
+
+//
+// Function to find an icon file somewhere in the system.  Return value is
+// the fully qualified path to the icon file if found, a null string otherwise.
+// 
+// iconname - the icon name to search for
+// filter - a string list containing an order preference for subdirectory names to return 
+// to search for,
+//
+// Called from the getIconName function
+QString IconManager::findQualifiedName(const QString& iconname, const QStringList& sl_filter)
+{
+	// variables
+	QStringList sl_results = QStringList();
+	
+	// get search paths
+	QStringList sl_dirs = QIcon::themeSearchPaths();
+	if (sl_dirs.size() < 1) return QString();
+
+	// iterate over the search paths 
+	for (int i = 0; i < sl_dirs.size(); ++i) { 
+		QDirIterator dit(QString(sl_dirs.at(i) + '/' + QIcon::themeName()) , QDirIterator::Subdirectories);
+		while (dit.hasNext()) {
+			QFileInfo fi(dit.next());
+			if (fi.completeBaseName() == iconname) sl_results << fi.canonicalFilePath();
+		}	// while
+	}	// for
+	
+	// search the list for icons matching the filter list and return first found
+	if (sl_results.size() < 1) return QString();
+	if (sl_filter.size() < 1) return sl_results.at(0);
+	for (int i = 0; i < sl_filter.size(); ++i) {
+		for (int j = 0; j < sl_results.size(); ++j) {	
+			if (sl_results.at(j).contains(sl_filter.at(i)) ) return sl_results.filter(sl_filter.at(i)).at(0);
+		}	// j for
+	}	// i for
+	
+	// if no filter matches
+	return sl_results.at(0);
+}
