@@ -2,7 +2,7 @@
 
 C++ main routine. 
 
-Copyright (C) 2013-2015
+Copyright (C) 2013-2017
 by: Andrew J. Bibb
 License: MIT
 
@@ -90,13 +90,13 @@ int main(int argc, char *argv[])
   QCommandLineOption disableTrayIcon(QStringList() << "d" << "disable-tray-icon",
 		QCoreApplication::translate("main.cpp", "Disable the system tray icon.  May be needed for system trays not compliant with the Freedesktop.org system tray specification.") );
   parser.addOption(disableTrayIcon);
-
+  
   parser.addHelpOption();
 
   QCommandLineOption useIconTheme(QStringList() << "i" << "icon-theme",
 		QCoreApplication::translate("main.cpp", "Use an icon theme from your system."),
 		QCoreApplication::translate("main.cpp", "Icon Theme Name"),
-		QString() );
+		QString("") );
   parser.addOption(useIconTheme);
 
   QCommandLineOption logInputRequest(QStringList() << "l" << "log-input-request",
@@ -106,6 +106,14 @@ int main(int argc, char *argv[])
   QCommandLineOption startMinimized(QStringList() << "m" << "minimized",
 		QCoreApplication::translate("main.cpp", "Start the GUI minimized in the system tray.") );
   parser.addOption(startMinimized);
+  
+  QCommandLineOption disableMinimize(QStringList() << "M" << "disable-minimize",
+		QCoreApplication::translate("main.cpp", "Disable the minimize button. Use when you want to have the window manager have sole control of minimizing the interface.") );
+  parser.addOption(disableMinimize);  
+  
+  QCommandLineOption disableVPN(QStringList() << "n" << "disable-vpn",
+		QCoreApplication::translate("main.cpp", "Disable VPN support.") );
+  parser.addOption(disableVPN);  
 
   parser.addVersionOption();
 
