@@ -2,7 +2,7 @@
 
 Code to manage the Provisioning Editor dialog.
 
-Copyright (C) 2013-2015
+Copyright (C) 2013-2017
 by: Andrew J. Bibb
 License: MIT
 
@@ -26,8 +26,6 @@ DEALINGS IN THE SOFTWARE.
 ***********************************************************************/
 
 # include <QtCore/QDebug>
-# include <QRegularExpression>
-# include <QRegularExpressionValidator>
 # include <QDBusMessage>
 # include <QDBusConnection>
 # include <QDBusInterface>
@@ -38,88 +36,14 @@ DEALINGS IN THE SOFTWARE.
 # include <QAction>
 # include <QFile>
 # include <QFileDialog>
+# include <QRegularExpression>
 
 # include "./prov_ed.h"
 # include "../resource.h"
 # include "./code/trstring/tr_strings.h"
-
-ValidatingDialog::ValidatingDialog(QWidget* parent) : QDialog(parent)
-{
-  // build the dialog
-  label = new QLabel(this);
-  lineedit = new QLineEdit(this);
-  buttonbox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, Qt::Horizontal, this);
-  this->setSizeGripEnabled(true);
-  
-  QVBoxLayout* vboxlayout = new QVBoxLayout;
-  vboxlayout->addWidget(label);
-  vboxlayout->addWidget(lineedit);
-  vboxlayout->addWidget(buttonbox);
-  this->setLayout(vboxlayout);
-
-  // signals and slots
-  connect(buttonbox, SIGNAL(accepted()), this, SLOT(accept()));
-  connect(buttonbox, SIGNAL(rejected()), this, SLOT(reject()));
-}
-
-// Slot to set the lineedit validator
-void ValidatingDialog::setValidator(const int& vd, bool plural)
-{
-  // setup a switch to set the validator
-  QString s_ip4   = "(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9]?[0-9])";
-  QString s_ip6   = "(?:[0-9a-fA-F]{1,4})";
-  QString s_mac   = "(?:[0-9a-fA-F]{1,2})";
-  QString s_hex   = "[0-9a-fA-F]*";
-  QString s_dom   = "[0-9a-zA-Z]*[\\.]?[0-9a-zA-Z]*";
-  QString s_wd    = "[0-9,a-zA-Z_\\.\\!\\@\\#\\$\\%\\^\\&\\*\\+\\-]*";
-  QString s_start = (plural ? "\\s?|(" : "\\s?|^");
-  QString s_end   = (plural ? "(\\s*[,|;|\\s]\\s*))+" : "$");
-  
-  switch (vd){
-    case CMST::ProvEd_Vd_IPv4: {
-      QRegularExpression rx4(s_start + s_ip4 + "(?:\\." + s_ip4 + "){3}" + s_end);
-      QRegularExpressionValidator* lev_4 = new QRegularExpressionValidator(rx4, this);
-      lineedit->setValidator(lev_4); }
-      break;
-    case CMST::ProvEd_Vd_IPv6: {
-      QRegularExpression rx6(s_start + s_ip6 + "(?::" + s_ip6 + "){7}" + s_end);
-      QRegularExpressionValidator* lev_6 = new QRegularExpressionValidator(rx6, this);
-      lineedit->setValidator(lev_6); }
-      break;
-    case CMST::ProvEd_Vd_MAC: {
-      QRegularExpression rxm(s_start + s_mac + "(?::" + s_mac + "){5}" + s_end);
-      QRegularExpressionValidator* lev_m = new QRegularExpressionValidator(rxm, this); 
-      lineedit->setValidator(lev_m); }
-      break;
-    case CMST::ProvEd_Vd_46: {
-      QRegularExpression rx46(s_start + "(" + s_ip4 + "(?:\\." + s_ip4 + "){3}|" + s_ip6 + "(?::" + s_ip6 + "){7})" + s_end);    
-      QRegularExpressionValidator* lev_46 = new QRegularExpressionValidator(rx46, this);  
-      lineedit->setValidator(lev_46); }
-      break;  
-    case CMST::ProvEd_Vd_Hex: {
-      QRegularExpression rxh(s_start + s_hex + s_end);
-      QRegularExpressionValidator* lev_h = new QRegularExpressionValidator(rxh, this);
-      lineedit->setValidator(lev_h); }
-      break;
-    case CMST::ProvEd_Vd_Dom: {
-      QRegularExpression rxdom(s_start + s_dom + s_end);
-      QRegularExpressionValidator* lev_dom = new QRegularExpressionValidator(rxdom, this);
-      lineedit->setValidator(lev_dom); }
-      break;
-    case CMST::ProvEd_Vd_Wd: {
-      QRegularExpression rxwd(s_start + s_wd + s_end);
-      QRegularExpressionValidator* lev_wd = new QRegularExpressionValidator(rxwd, this);
-      lineedit->setValidator(lev_wd); }
-      break;        
-    default:
-      lineedit->setValidator(0);
-      break;
-    } // switch     
-    
-  return;
-}
-   
-
+# include "./code/shared/shared.h"
+//
+// Provisioning Editor constructor
 ProvisioningEditor::ProvisioningEditor(QWidget* parent) : QDialog(parent)
 {
   // Setup the user interface
@@ -128,6 +52,7 @@ ProvisioningEditor::ProvisioningEditor(QWidget* parent) : QDialog(parent)
   // Data members
   menubar = new QMenuBar(this);
   ui.verticalLayout01->setMenuBar(menubar);
+  con_path = "/var/lib/connman";
 
   statusbar = new QStatusBar(this);
   ui.verticalLayout01->addWidget(statusbar);
@@ -144,6 +69,9 @@ ProvisioningEditor::ProvisioningEditor(QWidget* parent) : QDialog(parent)
   group_template = new QActionGroup(this);
   group_template->addAction(ui.actionTemplateEduroamLong);
   group_template->addAction(ui.actionTemplateEduroamShort);
+  group_template->addAction(ui.actionTemplateeap_peap);
+  group_template->addAction(ui.actionTemplateeap_tls);
+  group_template->addAction(ui.actionTemplateeap_ttls);
   
   group_freeform = new QActionGroup(this);
   group_freeform->addAction(ui.actionGlobal);
@@ -237,6 +165,10 @@ ProvisioningEditor::ProvisioningEditor(QWidget* parent) : QDialog(parent)
   menu_template = new QMenu(tr("Templates"), this);menu_template->addAction(ui.actionTemplateEduroamShort);
   menu_template->addAction(ui.actionTemplateEduroamLong);
   menu_template->addAction(ui.actionTemplateEduroamShort);
+  menu_template->addSeparator();
+  menu_template->addAction(ui.actionTemplateeap_peap);
+  menu_template->addAction(ui.actionTemplateeap_tls);
+  menu_template->addAction(ui.actionTemplateeap_ttls);
   
   // add menus to UI
   menubar->addMenu(menu_global);
@@ -294,16 +226,16 @@ void ProvisioningEditor::inputValidated(QAction* act)
   QString key = act->text();
   
   // create the dialog
-  ValidatingDialog* vd = new ValidatingDialog(this);
+  shared::ValidatingDialog* vd = new shared::ValidatingDialog(this);
   
   // create some prompts and set validator
-  if (act == ui.actionServiceMAC) {vd->setLabel(tr("MAC address.")); vd->setValidator(CMST::ProvEd_Vd_MAC);}
-  if (act == ui.actionWifiSSID) {vd->setLabel(tr("SSID: hexadecimal representation of an 802.11 SSID")), vd->setValidator(CMST:: ProvEd_Vd_Hex);}
-  if (act == ui.actionServiceNameServers) {vd->setLabel(tr("List of Nameservers")), vd->setValidator(CMST::ProvEd_Vd_46, true);}
-  if (act == ui.actionServiceTimeServers) {vd->setLabel(tr("List of Timeservers")), vd->setValidator(CMST::ProvEd_Vd_46, true);}
-  if (act == ui.actionServiceSearchDomains) {vd->setLabel(tr("List of DNS Search Domains")), vd->setValidator(CMST::ProvEd_Vd_Dom, true);}
-  if (act == ui.actionServiceDomain) {vd->setLabel(tr("Domain name to be used")), vd->setValidator(CMST::ProvEd_Vd_Dom);}
-  if (act == ui.actionWifiName) {vd->setLabel(tr("Enter the string representation of an 802.11 SSID.")), vd->setValidator(CMST::ProvEd_Vd_Wd);}
+  if (act == ui.actionServiceMAC) {vd->setLabel(tr("MAC address.")); vd->setValidator(CMST::ValDialog_MAC);}
+  if (act == ui.actionWifiSSID) {vd->setLabel(tr("SSID: hexadecimal representation of an 802.11 SSID")); vd->setValidator(CMST:: ValDialog_Hex);}
+  if (act == ui.actionServiceNameServers) {vd->setLabel(tr("List of Nameservers")); vd->setValidator(CMST::ValDialog_46d, true);}
+  if (act == ui.actionServiceTimeServers) {vd->setLabel(tr("List of Timeservers")); vd->setValidator(CMST::ValDialog_46d, true);}
+  if (act == ui.actionServiceSearchDomains) {vd->setLabel(tr("List of DNS Search Domains")); vd->setValidator(CMST::ValDialog_Dom, true);}
+  if (act == ui.actionServiceDomain) {vd->setLabel(tr("Domain name to be used")); vd->setValidator(CMST::ValDialog_Dom);}
+  if (act == ui.actionWifiName) {vd->setLabel(tr("Enter the string representation of an 802.11 SSID.")); vd->setValidator(CMST::ValDialog_Wd);}
   
   // if accepted put an entry in the textedit
   if (vd->exec() == QDialog::Accepted) {
@@ -342,18 +274,19 @@ void ProvisioningEditor::inputComboBox(QAction* act)
   if (act == ui.actionWifiPrivateKeyPassphraseType) {str = tr("Private key passphrase type."); sl << "fsid";}
   if (act == ui.actionWifiSecurity) {str = tr("Network security type."); sl << "psk" << "ieee8021x" << "wep" << "none";}
   if (act == ui.actionWifiHidden) {str = tr("Hidden network"); sl << "true" << "false";}
-  if (act == ui.actionServiceIPv6Privacy) {str = tr("IPv6 Privacy"); sl << "disabled" << "enabled" << "preferred";}
+  if (act == ui.actionServiceIPv6Privacy) {str = tr("IPv6 Privacy"); sl << "disabled" << "enabled" << "preferred";}	
   
+  QStringList sl_tr = TranslateStrings::cmtr_sl(sl);
   QString item = QInputDialog::getItem(this,
     tr("%1 - Item Input").arg(TranslateStrings::cmtr("cmst")),
     str,
-    sl,
+    sl_tr,
     0,
     false,
     &ok);
     
   key.append(" = %1\n");
-  if (ok) ui.plainTextEdit_main->insertPlainText(key.arg(item));
+  if (ok) ui.plainTextEdit_main->insertPlainText(key.arg(sl.at(sl_tr.indexOf(QRegularExpression(item)))) );
   
   return;
 }
@@ -418,19 +351,19 @@ void ProvisioningEditor::ipv4Triggered(QAction* act)
                                         "<p>Press OK when you are ready to proceed."),
                                         QMessageBox::Ok | QMessageBox::Abort,QMessageBox::Ok);
     if (but == QMessageBox::Ok) {
-      ValidatingDialog* vd = new ValidatingDialog(this);
+      shared::ValidatingDialog* vd = new shared::ValidatingDialog(this);
       vd->setLabel(tr("IPv4 Address"));
-      vd->setValidator(CMST::ProvEd_Vd_IPv4);
+      vd->setValidator(CMST::ValDialog_IPv4);
       if (vd->exec() == QDialog::Accepted && ! vd->getText().isEmpty() ) {
         val = vd->getText();
         vd->clear();
         vd->setLabel(tr("IPv4 Netmask")); 
-        vd->setValidator(CMST::ProvEd_Vd_IPv4);
+        vd->setValidator(CMST::ValDialog_IPv4);
         if (vd->exec() == QDialog::Accepted && ! vd->getText().isEmpty() ) {
           val.append("/" + vd->getText() );
           vd->clear();
           vd->setLabel(tr("IPv4 Gateway (This is an optional entry)")); 
-          vd->setValidator(CMST::ProvEd_Vd_IPv4);
+          vd->setValidator(CMST::ValDialog_IPv4);
           if (vd->exec() == QDialog::Accepted && ! vd->getText().isEmpty() ) { 
             val.append("/" + vd->getText() );
           } // if gateway accpted
@@ -463,9 +396,9 @@ void ProvisioningEditor::ipv6Triggered(QAction* act)
                                         "<p>Press OK when you are ready to proceed."),
                                         QMessageBox::Ok | QMessageBox::Abort,QMessageBox::Ok);
     if (but == QMessageBox::Ok) {
-      ValidatingDialog* vd = new ValidatingDialog(this);
+      shared::ValidatingDialog* vd = new shared::ValidatingDialog(this);
       vd->setLabel(tr("IPv6 Address"));
-      vd->setValidator(CMST::ProvEd_Vd_IPv6);
+      vd->setValidator(CMST::ValDialog_IPv6);
       if (vd->exec() == QDialog::Accepted && ! vd->getText().isEmpty() ) {
         val = vd->getText();
         int i = QInputDialog::getInt(this,
@@ -475,9 +408,9 @@ void ProvisioningEditor::ipv6Triggered(QAction* act)
           &ok);
         if (ok) {
           val.append(QString("/%1").arg(i) );
-          ValidatingDialog* vd = new ValidatingDialog(this);
+          shared::ValidatingDialog* vd = new shared::ValidatingDialog(this);
           vd->setLabel(tr("IPv6 Gateway (This is an optional entry)")); 
-          vd->setValidator(CMST::ProvEd_Vd_IPv6);
+          vd->setValidator(CMST::ValDialog_IPv6);
           if (vd->exec() == QDialog::Accepted && ! vd->getText().isEmpty() ) {
             val.append(QString("/" + vd->getText()) );
           } // if gateway was accepted
@@ -501,14 +434,18 @@ void ProvisioningEditor::templateTriggered(QAction* act)
   // get the source string depending on the action
   if (act == ui.actionTemplateEduroamLong) source = ":/text/text/eduroam_long.txt";
   else if (act == ui.actionTemplateEduroamShort) source = ":/text/text/eduroam_short.txt";
-  
+		else if (act == ui.actionTemplateeap_peap) source = ":/text/text/eap-peap.txt";
+			else if (act == ui.actionTemplateeap_tls) source = ":/text/text/eap-tls.txt";
+				else if (act == ui.actionTemplateeap_ttls) source = ":/text/text/eap-ttls.txt";
+					else return;
+
   // get the text
   QFile file(source);
   if (file.open(QIODevice::ReadOnly | QIODevice::Text)) {  
     QByteArray ba = file.readAll();
     
-    // seed the textedit with the template
-    this->seedTextEdit(QString(ba));
+    // append the template to the textedit
+    ui.plainTextEdit_main->appendPlainText(QString(ba) );
   } // if 
   
 
@@ -546,6 +483,7 @@ void ProvisioningEditor::requestFileList(QAbstractButton* button)
   
   // request a list of config files from roothelper
   QList<QVariant> vlist;
+  vlist << QVariant::fromValue(con_path);
   QDBusInterface* iface_rfl = new QDBusInterface("org.cmst.roothelper", "/", "org.cmst.roothelper", QDBusConnection::systemBus(), this);
   iface_rfl->callWithCallback(QLatin1String("getFileList"), vlist, this, SLOT(processFileList(const QStringList&)), SLOT(callbackErrorHandler(QDBusError)));
   
@@ -597,6 +535,7 @@ void ProvisioningEditor::processFileList(const QStringList& sl_conf)
     // if we have a filename try to open the file
     if (! filename.isEmpty() ) {
       vlist.clear();
+      vlist << QVariant::fromValue(con_path);
       vlist << QVariant::fromValue(filename); 
       iface_pfl->callWithCallback(QLatin1String("readFile"), vlist, this, SLOT(seedTextEdit(const QString&)), SLOT(callbackErrorHandler(QDBusError)));    
     } // if there is a file name
@@ -627,6 +566,7 @@ void ProvisioningEditor::processFileList(const QStringList& sl_conf)
     // if we have a filename try to delete the file
     if (! filename.isEmpty() ) {
       vlist.clear();
+      vlist << QVariant::fromValue(con_path);
       vlist << QVariant::fromValue(filename);
       iface_pfl->callWithCallback(QLatin1String("deleteFile"), vlist, this, SLOT(deleteCompleted(bool)), SLOT(callbackErrorHandler(QDBusError)));    
     } // if there is a file name
@@ -648,6 +588,7 @@ void ProvisioningEditor::processFileList(const QStringList& sl_conf)
     // if we have a filename try to save the file
     if (! filename.isEmpty() ) {
       vlist.clear();
+      vlist<< QVariant::fromValue(con_path);
       vlist << QVariant::fromValue(filename);
       vlist << QVariant::fromValue(ui.plainTextEdit_main->toPlainText() );
       iface_pfl->callWithCallback(QLatin1String("saveFile"), vlist, this, SLOT(writeCompleted(qint64)), SLOT(callbackErrorHandler(QDBusError)));   
@@ -662,8 +603,7 @@ void ProvisioningEditor::processFileList(const QStringList& sl_conf)
 
 //
 // Slot to seed the QTextEdit window with data read from file.  Connected to
-// fileReadCompleted signal in root helper.  Also called directly from
-// the templateTriggered slot. 
+// fileReadCompleted signal in root helper. 
 void ProvisioningEditor::seedTextEdit(const QString& data)
 {
   // clear the text edit and seed it with the read data
