@@ -4,7 +4,7 @@ Class to manage and present strings that need to be translated. These
 are typically not inline strings, rather strings used globally or strings
 returned by third parties, for instance, Connman.
 
-Copyright (C) 2013-2015
+Copyright (C) 2013-2017
 by: Andrew J. Bibb
 License: MIT
 
@@ -27,7 +27,6 @@ FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
 ***********************************************************************/
 
-# include <QStringList>
 
 # include "./tr_strings.h"
 
@@ -96,7 +95,8 @@ TranslateStrings::TranslateStrings(QObject* parent) : QObject(parent)
   
   sl << tr("disabled", "connman privacy string");
   sl << tr("enabled", "connman privacy string");
-  sl << tr("prefered", "connman privacy string");
+  sl << tr("prefered", "connman privacy string - known misspelling but needed to avoid breaking code");
+  sl << tr("preferred", "connman privacy string");
   
   sl << tr("auto", "connman ethernet connection method");
   sl << tr("manual", "connman ethernet connection method");
@@ -111,8 +111,27 @@ TranslateStrings::TranslateStrings(QObject* parent) : QObject(parent)
   sl << tr("6to4", "connman ipv6 method string");
   sl << tr("off", "connman ipv6 method string");
   
+  sl << tr("openconnect", "connman vpn connection type");
+  sl << tr("openvpn", "connman vpn connection type");
+  sl << tr("vpnc", "connman vpn connection type");
+  sl << tr("l2tp", "connman vpn connection type");
+  sl << tr("pptp", "connman vpn connection type");
+  
   	
 	return;
 }
 
+//
+// Function to return a stringlist with entries translated
+QStringList TranslateStrings::cmtr_sl(const QStringList& sl_src)
+{
+	QStringList sl_rtn;
+	sl_rtn.clear();
+	
+	for (int i = 0; i < sl_src.count(); ++i) {
+		sl_rtn << TranslateStrings::cmtr(sl_src.at(i) );
+	}
+	
+	return sl_rtn;
+}
 
