@@ -1,10 +1,10 @@
-/**************************** tr_strings.cpp ***************************
+/**************************** tr_strings.h ***************************
 
 Class to manage and present strings that need to be translated. These
 are typically not inline strings, rather strings used globally or strings
 returned by third parties, for instance, Connman.
 
-Copyright (C) 2013-2015
+Copyright (C) 2013-2017
 by: Andrew J. Bibb
 License: MIT
 
@@ -31,6 +31,8 @@ DEALINGS IN THE SOFTWARE.
 # define TRANSLATE_STRINGS
 
 # include <QObject>
+# include <QString>
+# include <QStringList>
 
 class TranslateStrings : public QObject
 {
@@ -42,5 +44,6 @@ class TranslateStrings : public QObject
   
   // functions
 		static inline QString cmtr(const QString& str, const char* disamb = 0) {return tr(qPrintable(str), disamb);}  
+		static QStringList cmtr_sl(const QStringList&);
 };
 #endif
