@@ -1,4 +1,4 @@
-	/**************************** resource.h *******************************
+  /**************************** resource.h *******************************
 
 Header file that contains program #defines.  It used to be that we kept
 all program update and version information in this single file.  Now
@@ -6,7 +6,7 @@ we've moved a lot of that to txt files inside the /text directory which
 are compiled in as a resource.  This seems to result in a faster 
 compile, but we now have manage information in two locations.
 
-Copyright (C) 2013-2015
+Copyright (C) 2013-2017
 by: Andrew J. Bibb
 License: MIT 
 
@@ -35,14 +35,15 @@ DEALINGS IN THE SOFTWARE.
 ///////////////////////////////// Program Values ///////////////////////
 //
 // Program Info (may be visible, but don't mark for tranalation) 
-#define VERSION "2015.12.03-1"
-#define RELEASE_DATE "3 December 2015"
-#define COPYRIGHT_DATE "2013-2015"
+#define VERSION "2017.03.18-1"
+
+#define RELEASE_DATE "18 March 2017"
+#define COPYRIGHT_DATE "2013-2017"
 
 // Program Values:
-//	QApplication (not user visible)
+//  QApplication (not user visible)
 //  QSettings (visible in filesystem only)
-//	System Logging (visible in system logs only)
+//  System Logging (visible in system logs only)
 #define LONG_NAME "CMST - Connman System Tray"
 #define ORG "cmst"
 #define APP "cmst"
@@ -51,6 +52,8 @@ DEALINGS IN THE SOFTWARE.
 // Program Values - Misc. (not user visible)
 #define SOCKET_NAME "cmst_single_app_socket"
 #define INTERNAL_THEME "CMST_Icon_Theme"
+#define IPT_REQ_LOG_PATH "/tmp/cmst"
+#define IPT_REQ_LOG_FILE "input_request.log"
 
 //////////////////////////// CMST Namespace/////////////////////////////
 //  Used for enum's local to this program
@@ -58,12 +61,13 @@ namespace CMST
 {
   enum {
     // errors
-    No_Errors         = 0x00,
-    Err_No_DBus       = (1 << 0), // Can't find DBus 
-    Err_Invalid_Iface = (1 << 1), // Invalid interface
-    Err_Properties    = (1 << 2), // There was an error reading connman.Manager.GetProperties
-    Err_Technologies  = (1 << 3), // There was an error reading connman.Manager.GetTechnologies       
-    Err_Services      = (1 << 4), // There was an error reading connman.Manager.GetServices  
+    No_Errors             = 0x00,
+    Err_No_DBus           = (1 << 0), // Can't find DBus 
+    Err_Invalid_Con_Iface = (1 << 1), // Invalid interface
+    Err_Properties        = (1 << 2), // There was an error reading connman.Manager.GetProperties
+    Err_Technologies      = (1 << 3), // There was an error reading connman.Manager.GetTechnologies       
+    Err_Services          = (1 << 4), // There was an error reading connman.Manager.GetServices 
+    Err_Invalid_VPN_Iface = (1 << 5), // Invalid interface 
     
     // methods
     Manager_Properties    = (1 << 1), // scan for properties
@@ -77,16 +81,21 @@ namespace CMST
     ProvEd_File_Delete  = (1 << 1),
     ProvEd_File_Write   = (1 << 2),
     
-    // provisioning editor validator input
-    ProvEd_Vd_None    = 0x00,
-    ProvEd_Vd_IPv4    = (1 << 0),
-    ProvEd_Vd_IPv6    = (1 << 1),
-    ProvEd_Vd_MAC     = (1 << 2),
-    ProvEd_Vd_46      = (1 << 3),
-    ProvEd_Vd_Hex     = (1 << 4),
-    ProvEd_Vd_Dom     = (1 << 5),
-    ProvEd_Vd_Wd      = (1 << 6),
-  };	// enum
+    // validating dialog validator input
+    ValDialog_None    = 0x00,
+    ValDialog_IPv4    = 0x01,
+    ValDialog_IPv6    = 0x02,
+    ValDialog_MAC     = 0x03,
+    ValDialog_46      = 0x04,
+    ValDialog_Hex     = 0x05,
+    ValDialog_Int     = 0x06,
+    ValDialog_Dom     = 0x07,
+    ValDialog_Wd      = 0x08,
+    ValDialog_min1ch  = 0x09,
+    ValDialog_min8ch  = 0x0a,
+    ValDialog_46d     = 0x0b,
+    
+  };  // enum
 } // namespace CMST
 
 #endif
